==> jc-1.4.0.tar.gz: soot/options/SETOptions.c <==
// public class soot.options.SETOptions

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class e283f7c2e7a7979c java_util_Map
// @dep_class 177db6dd531c9085 soot_PhaseOptions
// @dep_class 608cfcddf2720e73 soot_options_SETOptions

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Map
// @dep_header soot_PhaseOptions
// @dep_header soot_options_SETOptions

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Map.h"
#include "soot/PhaseOptions.h"
#include "soot/options/SETOptions.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private java.util.Map options
static _jc_field _jc_soot_options_SETOptions$field_info$options = {
	.name=		"options",
	.signature=	"Ljava/util/Map;",
	.class=		&_jc_soot_options_SETOptions$type,
	.type=		&_jc_java_util_Map$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_soot_options_SETOptions$object, refs[-1].soot_options_SETOptions.options),
};

// Fields
static _jc_field *const _jc_soot_options_SETOptions$fields[] = {
	&_jc_soot_options_SETOptions$field_info$options
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.util.Map)
//

static _jc_linenum _jc_soot_options_SETOptions$linenum_table$_init$39bc1e191d75104e[];

static const unsigned char _jc_soot_options_SETOptions$param_ptypes$_init$39bc1e191d75104e[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_options_SETOptions$param_types$_init$39bc1e191d75104e[] = {
	&_jc_java_util_Map$type
};

_jc_method _jc_soot_options_SETOptions$method_info$_init$39bc1e191d75104e = {
	.name=			"<init>",
	.signature=		"(Ljava/util/Map;)V",
	.class=			&_jc_soot_options_SETOptions$type,
	.param_types=		&_jc_soot_options_SETOptions$param_types$_init$39bc1e191d75104e,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_options_SETOptions$param_ptypes$_init$39bc1e191d75104e,
	.signature_hash=	_JC_JLONG(0x39bc1e191d75104e),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_options_SETOptions$method$_init$39bc1e191d75104e,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_soot_options_SETOptions$linenum_table$_init$39bc1e191d75104e
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_options_SETOptions, _init$39bc1e191d75104e);

void
_jc_soot_options_SETOptions$method$_init$39bc1e191d75104e(_jc_env *const env, _jc_soot_options_SETOptions$object *this, _jc_object *param0)
{
	struct _jc_soot_options_SETOptions$object *r0;
	struct _jc_object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(32);				// 0
	_JC_REF_FIELD(env, r0, soot_options_SETOptions, options) = r1;
	_JC_LINE_NUMBER(33);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public boolean enabled()
//

static _jc_linenum _jc_soot_options_SETOptions$linenum_table$enabled$e29aaa88d18be18b[];

static const unsigned char _jc_soot_options_SETOptions$param_ptypes$enabled$e29aaa88d18be18b[] = { 
_JC_TYPE_BOOLEAN };

_jc_method _jc_soot_options_SETOptions$method_info$enabled$e29aaa88d18be18b = {
	.name=			"enabled",
	.signature=		"()Z",
	.class=			&_jc_soot_options_SETOptions$type,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_soot_options_SETOptions$param_ptypes$enabled$e29aaa88d18be18b,
	.signature_hash=	_JC_JLONG(0xe29aaa88d18be18b),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_options_SETOptions$method$enabled$e29aaa88d18be18b,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_options_SETOptions$vtable, soot_options_SETOptions.enabled$e29aaa88d18be18b) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_options_SETOptions$linenum_table$enabled$e29aaa88d18be18b
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_options_SETOptions, enabled$e29aaa88d18be18b);

jboolean
_jc_soot_options_SETOptions$method$enabled$e29aaa88d18be18b(_jc_env *const env, _jc_soot_options_SETOptions$object *this)
{
	struct _jc_soot_options_SETOptions$object *r0;
	struct _jc_object *r1;
	struct _jc_java_lang_String$object *r3;
	struct _jc_java_lang_Object$object *r4;
	jboolean z1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(42);				// 0
	r1 = _JC_REF_FIELD(env, r0, soot_options_SETOptions, options);
	_JC_ACTIVE_USE(env, soot_PhaseOptions);
	r3 = _JC_STRING(env, "enabled");
	z1 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0x5db565349ffc17b2), jboolean, r3);
	if (z1 == 0)
		goto label0;
	r4 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0xb30461fc5ea13399), _jc_object *, r3);
	z1 = _JC_INVOKE_VIRTUAL(env, java_lang_Object, equals$8a15e0625571c581, r4, _JC_STRING(env, "true"));
	if (z1 == 0)
		goto label0;
	z1 = 1;
	goto label1;

label0:
	z1 = 0;

label1:
	return z1;
}

//
// public boolean naive()
//

static _jc_linenum _jc_soot_options_SETOptions$linenum_table$naive$8deba6a4c489ca51[];

static const unsigned char _jc_soot_options_SETOptions$param_ptypes$naive$8deba6a4c489ca51[] = { 
_JC_TYPE_BOOLEAN };

_jc_method _jc_soot_options_SETOptions$method_info$naive$8deba6a4c489ca51 = {
	.name=			"naive",
	.signature=		"()Z",
	.class=			&_jc_soot_options_SETOptions$type,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_soot_options_SETOptions$param_ptypes$naive$8deba6a4c489ca51,
	.signature_hash=	_JC_JLONG(0x8deba6a4c489ca51),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_options_SETOptions$method$naive$8deba6a4c489ca51,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_options_SETOptions$vtable, soot_options_SETOptions.naive$8deba6a4c489ca51) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_options_SETOptions$linenum_table$naive$8deba6a4c489ca51
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_options_SETOptions, naive$8deba6a4c489ca51);

jboolean
_jc_soot_options_SETOptions$method$naive$8deba6a4c489ca51(_jc_env *const env, _jc_soot_options_SETOptions$object *this)
{
	struct _jc_soot_options_SETOptions$object *r0;
	struct _jc_object *r1;
	struct _jc_java_lang_String$object *r3;
	struct _jc_java_lang_Object$object *r4;
	jboolean z1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(56);				// 0
	r1 = _JC_REF_FIELD(env, r0, soot_options_SETOptions, options);
	_JC_ACTIVE_USE(env, soot_PhaseOptions);
	r3 = _JC_STRING(env, "naive");
	z1 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0x5db565349ffc17b2), jboolean, r3);
	if (z1 == 0)
		goto label0;
	r4 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0xb30461fc5ea13399), _jc_object *, r3);
	z1 = _JC_INVOKE_VIRTUAL(env, java_lang_Object, equals$8a15e0625571c581, r4, _JC_STRING(env, "true"));
	if (z1 == 0)
		goto label0;
	z1 = 1;
	goto label1;

label0:
	z1 = 0;

label1:
	return z1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_options_SETOptions$methods[] = {
	&_jc_soot_options_SETOptions$method_info$_init$39bc1e191d75104e,
	&_jc_soot_options_SETOptions$method_info$enabled$e29aaa88d18be18b,
	&_jc_soot_options_SETOptions$method_info$naive$8deba6a4c489ca51
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_options_SETOptions$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_options_SETOptions$instanceof_hash_bucket_115[] = {
	&_jc_soot_options_SETOptions$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_options_SETOptions$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[113]=	_jc_soot_options_SETOptions$instanceof_hash_bucket_113,
	[115]=	_jc_soot_options_SETOptions$instanceof_hash_bucket_115
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_options_SETOptions$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/util/Map",	_JC_JLONG(0xe283f7c2e7a7979c) },
	{ "soot/PhaseOptions",	_JC_JLONG(0x177db6dd531c9085) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_options_SETOptions$vtype _jc_soot_options_SETOptions$type = {
    .type= {
	.name=			"soot/options/SETOptions",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x608cfcddf2720e73),
		.source_file=		"SETOptions.java",
		.instance_size=		sizeof(_jc_soot_options_SETOptions$refs) + sizeof(_jc_soot_options_SETOptions$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_soot_options_SETOptions$fields) / sizeof(*_jc_soot_options_SETOptions$fields),
		.fields=		_jc_soot_options_SETOptions$fields,
		.num_methods=		sizeof(_jc_soot_options_SETOptions$methods) / sizeof(*_jc_soot_options_SETOptions$methods),
		.methods=		_jc_soot_options_SETOptions$methods,
		.instanceof_hash_table=	_jc_soot_options_SETOptions$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_options_SETOptions$class_depends) / sizeof(*_jc_soot_options_SETOptions$class_depends),
		.class_depends=		_jc_soot_options_SETOptions$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_options_SETOptions= {
	    .enabled$e29aaa88d18be18b=
		&_jc_soot_options_SETOptions$method$enabled$e29aaa88d18be18b,
	    .naive$8deba6a4c489ca51=
		&_jc_soot_options_SETOptions$method$naive$8deba6a4c489ca51,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/options/SETOptions.c <==
// public class soot.options.SETOptions

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class e283f7c2e7a7979c java_util_Map
// @dep_class 177db6dd531c9085 soot_PhaseOptions
// @dep_class 608cfcddf2720e73 soot_options_SETOptions

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Map
// @dep_header soot_PhaseOptions
// @dep_header soot_options_SETOptions

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Map.h"
#include "soot/PhaseOptions.h"
#include "soot/options/SETOptions.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private java.util.Map options
static _jc_field _jc_soot_options_SETOptions$field_info$options = {
	.name=		"options",
	.signature=	"Ljava/util/Map;",
	.class=		&_jc_soot_options_SETOptions$type,
	.type=		&_jc_java_util_Map$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_soot_options_SETOptions$object, refs[-1].soot_options_SETOptions.options),
};

// Fields
static _jc_field *const _jc_soot_options_SETOptions$fields[] = {
	&_jc_soot_options_SETOptions$field_info$options
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.util.Map)
//

static _jc_linenum _jc_soot_options_SETOptions$linenum_table$_init$39bc1e191d75104e[];

static const unsigned char _jc_soot_options_SETOptions$param_ptypes$_init$39bc1e191d75104e[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_options_SETOptions$param_types$_init$39bc1e191d75104e[] = {
	&_jc_java_util_Map$type
};

_jc_method _jc_soot_options_SETOptions$method_info$_init$39bc1e191d75104e = {
	.name=			"<init>",
	.signature=		"(Ljava/util/Map;)V",
	.class=			&_jc_soot_options_SETOptions$type,
	.param_types=		&_jc_soot_options_SETOptions$param_types$_init$39bc1e191d75104e,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_options_SETOptions$param_ptypes$_init$39bc1e191d75104e,
	.signature_hash=	_JC_JLONG(0x39bc1e191d75104e),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_options_SETOptions$method$_init$39bc1e191d75104e,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_soot_options_SETOptions$linenum_table$_init$39bc1e191d75104e
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_options_SETOptions, _init$39bc1e191d75104e);

void _JC_JCNI_ATTR
_jc_soot_options_SETOptions$method$_init$39bc1e191d75104e(_jc_env *const env, _jc_soot_options_SETOptions$object *this, _jc_object *param0)
{
	struct _jc_soot_options_SETOptions$object *r0;
	struct _jc_object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(32);				// 0
	_JC_REF_FIELD(env, r0, soot_options_SETOptions, options) = r1;
	_JC_LINE_NUMBER(33);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public boolean enabled()
//

static _jc_linenum _jc_soot_options_SETOptions$linenum_table$enabled$e29aaa88d18be18b[];

static const unsigned char _jc_soot_options_SETOptions$param_ptypes$enabled$e29aaa88d18be18b[] = { 
_JC_TYPE_BOOLEAN };

_jc_method _jc_soot_options_SETOptions$method_info$enabled$e29aaa88d18be18b = {
	.name=			"enabled",
	.signature=		"()Z",
	.class=			&_jc_soot_options_SETOptions$type,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_soot_options_SETOptions$param_ptypes$enabled$e29aaa88d18be18b,
	.signature_hash=	_JC_JLONG(0xe29aaa88d18be18b),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_options_SETOptions$method$enabled$e29aaa88d18be18b,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_options_SETOptions$vtable, soot_options_SETOptions.enabled$e29aaa88d18be18b) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_options_SETOptions$linenum_table$enabled$e29aaa88d18be18b
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_options_SETOptions, enabled$e29aaa88d18be18b);

jboolean _JC_JCNI_ATTR
_jc_soot_options_SETOptions$method$enabled$e29aaa88d18be18b(_jc_env *const env, _jc_soot_options_SETOptions$object *this)
{
	struct _jc_soot_options_SETOptions$object *r0;
	struct _jc_object *r1;
	struct _jc_java_lang_String$object *r3;
	struct _jc_java_lang_Object$object *r4;
	jboolean z1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(42);				// 0
	r1 = _JC_REF_FIELD(env, r0, soot_options_SETOptions, options);
	_JC_ACTIVE_USE(env, soot_PhaseOptions);
	r3 = _JC_STRING(env, "enabled");
	z1 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0x5db565349ffc17b2), jboolean, (_jc_env *, struct _jc_object *, struct _jc_java_lang_Object$object *), r3);
	if (z1 == 0)
		goto label0;
	r4 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0xb30461fc5ea13399), _jc_object *, (_jc_env *, struct _jc_object *, struct _jc_java_lang_Object$object *), r3);
	z1 = _JC_INVOKE_VIRTUAL(env, java_lang_Object, equals$8a15e0625571c581, r4, _JC_STRING(env, "true"));
	if (z1 == 0)
		goto label0;
	z1 = 1;
	goto label1;

label0:
	z1 = 0;

label1:
	return z1;
}

//
// public boolean naive()
//

static _jc_linenum _jc_soot_options_SETOptions$linenum_table$naive$8deba6a4c489ca51[];

static const unsigned char _jc_soot_options_SETOptions$param_ptypes$naive$8deba6a4c489ca51[] = { 
_JC_TYPE_BOOLEAN };

_jc_method _jc_soot_options_SETOptions$method_info$naive$8deba6a4c489ca51 = {
	.name=			"naive",
	.signature=		"()Z",
	.class=			&_jc_soot_options_SETOptions$type,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_soot_options_SETOptions$param_ptypes$naive$8deba6a4c489ca51,
	.signature_hash=	_JC_JLONG(0x8deba6a4c489ca51),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_options_SETOptions$method$naive$8deba6a4c489ca51,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_options_SETOptions$vtable, soot_options_SETOptions.naive$8deba6a4c489ca51) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_options_SETOptions$linenum_table$naive$8deba6a4c489ca51
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_options_SETOptions, naive$8deba6a4c489ca51);

jboolean _JC_JCNI_ATTR
_jc_soot_options_SETOptions$method$naive$8deba6a4c489ca51(_jc_env *const env, _jc_soot_options_SETOptions$object *this)
{
	struct _jc_soot_options_SETOptions$object *r0;
	struct _jc_object *r1;
	struct _jc_java_lang_String$object *r3;
	struct _jc_java_lang_Object$object *r4;
	jboolean z1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(56);				// 0
	r1 = _JC_REF_FIELD(env, r0, soot_options_SETOptions, options);
	_JC_ACTIVE_USE(env, soot_PhaseOptions);
	r3 = _JC_STRING(env, "naive");
	z1 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0x5db565349ffc17b2), jboolean, (_jc_env *, struct _jc_object *, struct _jc_java_lang_Object$object *), r3);
	if (z1 == 0)
		goto label0;
	r4 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0xb30461fc5ea13399), _jc_object *, (_jc_env *, struct _jc_object *, struct _jc_java_lang_Object$object *), r3);
	z1 = _JC_INVOKE_VIRTUAL(env, java_lang_Object, equals$8a15e0625571c581, r4, _JC_STRING(env, "true"));
	if (z1 == 0)
		goto label0;
	z1 = 1;
	goto label1;

label0:
	z1 = 0;

label1:
	return z1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_options_SETOptions$methods[] = {
	&_jc_soot_options_SETOptions$method_info$_init$39bc1e191d75104e,
	&_jc_soot_options_SETOptions$method_info$enabled$e29aaa88d18be18b,
	&_jc_soot_options_SETOptions$method_info$naive$8deba6a4c489ca51
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_options_SETOptions$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_options_SETOptions$instanceof_hash_bucket_115[] = {
	&_jc_soot_options_SETOptions$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_options_SETOptions$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[101]=	_jc_soot_options_SETOptions$instanceof_hash_bucket_101,
	[115]=	_jc_soot_options_SETOptions$instanceof_hash_bucket_115
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_options_SETOptions$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/util/Map",	_JC_JLONG(0xe283f7c2e7a7979c) },
	{ "soot/PhaseOptions",	_JC_JLONG(0x177db6dd531c9085) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_options_SETOptions$vtype _jc_soot_options_SETOptions$type = {
    .type= {
	.name=			"soot/options/SETOptions",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x608cfcddf2720e73),
		.source_file=		"SETOptions.java",
		.instance_size=		sizeof(_jc_soot_options_SETOptions$refs) + sizeof(_jc_soot_options_SETOptions$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_soot_options_SETOptions$fields) / sizeof(*_jc_soot_options_SETOptions$fields),
		.fields=		_jc_soot_options_SETOptions$fields,
		.num_methods=		sizeof(_jc_soot_options_SETOptions$methods) / sizeof(*_jc_soot_options_SETOptions$methods),
		.methods=		_jc_soot_options_SETOptions$methods,
		.instanceof_hash_table=	_jc_soot_options_SETOptions$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_options_SETOptions$class_depends) / sizeof(*_jc_soot_options_SETOptions$class_depends),
		.class_depends=		_jc_soot_options_SETOptions$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_options_SETOptions= {
	    .enabled$e29aaa88d18be18b=
		&_jc_soot_options_SETOptions$method$enabled$e29aaa88d18be18b,
	    .naive$8deba6a4c489ca51=
		&_jc_soot_options_SETOptions$method$naive$8deba6a4c489ca51,
	},
    }
};
